@@ -1,5 +1,6 @@
 """SQLAlchemy models for Social Auth"""
 import base64
+import six
 
 # from sqlalchemy.orm import Query
 from sqlalchemy.exc import IntegrityError
@@ -59,9 +60,9 @@ class SQLAlchemyUserMixin(SQLAlchemyMixin, UserMixin):
         if cls.allowed_to_disconnect(user, name, association_id):
             qs = cls.get_social_auth_for_user(user)
             if association_id:
-                qs = qs.filter(cls.id == association_id)
+                qs = qs.filter_by(id=association_id)
             else:
-                qs = qs.filter(cls.provider == name)
+                qs = qs.filter_by(provider=name)
             qs.delete()
         else:
             raise NotAllowedToDisconnect()
@@ -93,7 +94,7 @@ class SQLAlchemyUserMixin(SQLAlchemyMixin, UserMixin):
 
     @classmethod
     def get_social_auth(cls, provider, uid):
-        if not isinstance(uid, basestring):
+        if not isinstance(uid, six.string_types):
             uid = str(uid)
         try:
             return cls._query().filter_by(provider=provider,
@@ -103,11 +104,11 @@ class SQLAlchemyUserMixin(SQLAlchemyMixin, UserMixin):
 
     @classmethod
     def get_social_auth_for_user(cls, user):
-        return user.social_auth
+        return cls._query().filter_by(user_id=user.id)
 
     @classmethod
     def create_social_auth(cls, user, uid, provider):
-        if not isinstance(uid, basestring):
+        if not isinstance(uid, six.string_types):
             uid = str(uid)
         return cls._new_instance(cls, user=user, uid=uid, provider=provider)
 
