@@ -2,7 +2,7 @@ import time
 import random
 import hashlib
 
-from social.utils import setting_name
+from social.utils import setting_name, to_setting_name
 from social.store import OpenIdStore
 
 
@@ -50,6 +50,7 @@ class BaseStrategy(object):
     def setting(self, name, default=None):
         names = (setting_name(self.backend_name, name),
                  setting_name(name),
+                 to_setting_name(self.backend_name, name),
                  name)
         for name in names:
             try:
@@ -101,8 +102,8 @@ class BaseStrategy(object):
         }
 
     def from_session(self, session):
-        return session['next'], session['backend'], \
-               session['args'], session['kwargs']
+        return (session['next'], session['backend'],
+                session['args'], session['kwargs'])
 
     def clean_partial_pipeline(self):
         self.session_pop('partial_pipeline')
@@ -117,8 +118,7 @@ class BaseStrategy(object):
             'social.pipeline.user.create_user',
             'social.pipeline.social_auth.associate_user',
             'social.pipeline.social_auth.load_extra_data',
-            'social.pipeline.user.user_details'
-       ))
+            'social.pipeline.user.user_details'))
 
     def random_string(self, length=12, chars=ALLOWED_CHARS):
         # Implementation borrowed from django 1.4
